@@ -1,7 +1,6 @@
 
-__version__ = '1.1.1'
+__version__ = '1.1.2'
 
-import os
 import sys
 import timeit
 import inspect
@@ -16,16 +15,16 @@ try:
 except ImportError:
     import profile as profile_module
 
-# Django installed but there is no django configuration.
-if 'DJANGO_SETTINGS_MODULE' in os.environ:
-    try:
+try:
+    from django.conf import settings
+except ImportError:
+    settings = None
+
+try:
+    if settings.configured:
         from django.db import connection
-    except ImportError:
-        connection = None
-    try:
-        from django.conf import settings
-    except ImportError:
-        settings = None
+except (ImportError, AttributeError):
+    connection = None
 
 
 class Profiler(object):
